==> cognito-local-3.20.0.tgz: package/lib/targets/adminGetUser.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __markAsModule = (target) => __defProp(target, "__esModule", { value: true });
var __export = (target, all) => {
  __markAsModule(target);
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __reExport = (target, module2, desc) => {
  if (module2 && typeof module2 === "object" || typeof module2 === "function") {
    for (let key of __getOwnPropNames(module2))
      if (!__hasOwnProp.call(target, key) && key !== "default")
        __defProp(target, key, { get: () => module2[key], enumerable: !(desc = __getOwnPropDesc(module2, key)) || desc.enumerable });
  }
  return target;
};
var __toModule = (module2) => {
  return __reExport(__markAsModule(__defProp(module2 != null ? __create(__getProtoOf(module2)) : {}, "default", module2 && module2.__esModule && "default" in module2 ? { get: () => module2.default, enumerable: true } : { value: module2, enumerable: true })), module2);
};
__export(exports, {
  AdminGetUser: () => AdminGetUser
});
var import_errors = __toModule(require("../errors"));
const AdminGetUser = ({ cognito }) => async (ctx, req) => {
  const userPool = await cognito.getUserPool(ctx, req.UserPoolId);
  const user = await userPool.getUserByUsername(ctx, req.Username);
  if (!user) {
    throw new import_errors.UserNotFoundError("User does not exist");
  }
  return {
    Enabled: user.Enabled,
    MFAOptions: user.MFAOptions,
    PreferredMfaSetting: void 0,
    UserAttributes: user.Attributes,
    UserCreateDate: user.UserCreateDate,
    UserLastModifiedDate: user.UserLastModifiedDate,
    UserMFASettingList: void 0,
    Username: user.Username,
    UserStatus: user.UserStatus
  };
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  AdminGetUser
});

==> cognito-local-3.23.3.tgz: package/lib/targets/adminGetUser.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __markAsModule = (target) => __defProp(target, "__esModule", { value: true });
var __export = (target, all) => {
  __markAsModule(target);
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __reExport = (target, module2, desc) => {
  if (module2 && typeof module2 === "object" || typeof module2 === "function") {
    for (let key of __getOwnPropNames(module2))
      if (!__hasOwnProp.call(target, key) && key !== "default")
        __defProp(target, key, { get: () => module2[key], enumerable: !(desc = __getOwnPropDesc(module2, key)) || desc.enumerable });
  }
  return target;
};
var __toModule = (module2) => {
  return __reExport(__markAsModule(__defProp(module2 != null ? __create(__getProtoOf(module2)) : {}, "default", module2 && module2.__esModule && "default" in module2 ? { get: () => module2.default, enumerable: true } : { value: module2, enumerable: true })), module2);
};
__export(exports, {
  AdminGetUser: () => AdminGetUser
});
var import_errors = __toModule(require("../errors"));
const AdminGetUser = ({ cognito }) => async (ctx, req) => {
  const userPool = await cognito.getUserPool(ctx, req.UserPoolId);
  const user = await userPool.getUserByUsername(ctx, req.Username);
  if (!user) {
    throw new import_errors.UserNotFoundError("User does not exist.");
  }
  return {
    Enabled: user.Enabled,
    MFAOptions: user.MFAOptions,
    PreferredMfaSetting: void 0,
    UserAttributes: user.Attributes,
    UserCreateDate: user.UserCreateDate,
    UserLastModifiedDate: user.UserLastModifiedDate,
    UserMFASettingList: void 0,
    Username: user.Username,
    UserStatus: user.UserStatus
  };
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  AdminGetUser
});
